==> com.liferay.layout.content.page.editor.web-1.0.20.jar: META-INF/resources/js/utils/rowConstants.js <==
"use strict";

Liferay.Loader.define("layout-content-page-editor-web@1.0.20/js/utils/rowConstants", ['module', 'exports', 'require'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.DEFAULT_SECTION_ROW_CONFIG = exports.DEFAULT_COMPONENT_ROW_CONFIG = exports.PADDING_OPTIONS = exports.NUMBER_OF_COLUMNS_OPTIONS = exports.MAX_COLUMNS = exports.CONFIG_KEYS = exports.CONTAINER_TYPES = void 0;

  var _DEFAULT_COMPONENT_RO, _DEFAULT_SECTION_ROW_;

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  /**
   * Available values for containerType config key
   */
  var CONTAINER_TYPES = [{
    containerTypeId: 'fixed',
    label: Liferay.Language.get('fixed-width')
  }, {
    containerTypeId: 'fluid',
    label: Liferay.Language.get('fluid')
  }];
  /**
   * Available element config keys
   */

  exports.CONTAINER_TYPES = CONTAINER_TYPES;
  var CONFIG_KEYS = {
    backgroundColorCssClass: 'backgroundColorCssClass',
    columnSpacing: 'columnSpacing',
    containerType: 'containerType',
    paddingHorizontal: 'paddingHorizontal',
    paddingVertical: 'paddingVertical'
  };
  /**
   * Default padding size
   */

  exports.CONFIG_KEYS = CONFIG_KEYS;
  var DEFAULT_PADDING_SIZE = '3';
  /**
   * Max row columns
   */

  var MAX_COLUMNS = 12;
  /**
   * Available values for containerType config key
   */

  exports.MAX_COLUMNS = MAX_COLUMNS;
  var NUMBER_OF_COLUMNS_OPTIONS = [{
    label: '1',
    numberOfColumnId: '1'
  }, {
    label: '2',
    numberOfColumnId: '2'
  }, {
    label: '3',
    numberOfColumnId: '3'
  }, {
    label: '4',
    numberOfColumnId: '4'
  }, {
    label: '5',
    numberOfColumnId: '5'
  }, {
    label: '6',
    numberOfColumnId: '6'
  }];
  /**
   * Available values for padding (horizontal and vertical) config key
   */

  exports.NUMBER_OF_COLUMNS_OPTIONS = NUMBER_OF_COLUMNS_OPTIONS;
  var PADDING_OPTIONS = [{
    label: 'x0',
    paddingSize: '0'
  }, {
    label: 'x1',
    paddingSize: '3'
  }, {
    label: 'x2',
    paddingSize: '4'
  }, {
    label: 'x4',
    paddingSize: '5'
  }, {
    label: 'x6',
    paddingSize: '6'
  }, {
    label: 'x8',
    paddingSize: '7'
  }, {
    label: 'x10',
    paddingSize: '8'
  }];
  /**
   * Default component row config
   */

  exports.PADDING_OPTIONS = PADDING_OPTIONS;
  var DEFAULT_COMPONENT_ROW_CONFIG = (_DEFAULT_COMPONENT_RO = {}, _defineProperty(_DEFAULT_COMPONENT_RO, CONFIG_KEYS.columnSpacing, true), _defineProperty(_DEFAULT_COMPONENT_RO, CONFIG_KEYS.paddingHorizontal, DEFAULT_PADDING_SIZE), _defineProperty(_DEFAULT_COMPONENT_RO, CONFIG_KEYS.paddingVertical, DEFAULT_PADDING_SIZE), _DEFAULT_COMPONENT_RO);
  /**
   * Default section row config
   */

  exports.DEFAULT_COMPONENT_ROW_CONFIG = DEFAULT_COMPONENT_ROW_CONFIG;
  var DEFAULT_SECTION_ROW_CONFIG = (_DEFAULT_SECTION_ROW_ = {}, _defineProperty(_DEFAULT_SECTION_ROW_, CONFIG_KEYS.columnSpacing, true), _defineProperty(_DEFAULT_SECTION_ROW_, CONFIG_KEYS.paddingHorizontal, '0'), _defineProperty(_DEFAULT_SECTION_ROW_, CONFIG_KEYS.paddingVertical, '0'), _DEFAULT_SECTION_ROW_);
  exports.DEFAULT_SECTION_ROW_CONFIG = DEFAULT_SECTION_ROW_CONFIG;
  //# sourceMappingURL=rowConstants.js.map
});
//# sourceMappingURL=rowConstants.js.map

==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/utils/rowConstants.js <==
Liferay.Loader.define('layout-content-page-editor-web@1.0.52/js/utils/rowConstants', ['module', 'exports', 'require'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.DEFAULT_SECTION_ROW_CONFIG = exports.DEFAULT_COMPONENT_ROW_CONFIG = exports.PADDING_OPTIONS = exports.NUMBER_OF_COLUMNS_OPTIONS = exports.MAX_COLUMNS = exports.CONFIG_KEYS = exports.CONTAINER_TYPES = void 0;

  var _DEFAULT_COMPONENT_RO, _DEFAULT_SECTION_ROW_;

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */

  /**
   * Available values for containerType config key
   */
  var CONTAINER_TYPES = [{
    containerTypeId: 'fixed',
    label: Liferay.Language.get('fixed-width')
  }, {
    containerTypeId: 'fluid',
    label: Liferay.Language.get('fluid')
  }];
  /**
   * Available element config keys
   */

  exports.CONTAINER_TYPES = CONTAINER_TYPES;
  var CONFIG_KEYS = {
    backgroundColorCssClass: 'backgroundColorCssClass',
    columnSpacing: 'columnSpacing',
    containerType: 'containerType',
    paddingHorizontal: 'paddingHorizontal',
    paddingVertical: 'paddingVertical'
  };
  /**
   * Default padding size
   */

  exports.CONFIG_KEYS = CONFIG_KEYS;
  var DEFAULT_PADDING_SIZE = '3';
  /**
   * Max row columns
   */

  var MAX_COLUMNS = 12;
  /**
   * Available values for containerType config key
   */

  exports.MAX_COLUMNS = MAX_COLUMNS;
  var NUMBER_OF_COLUMNS_OPTIONS = [{
    label: '1',
    numberOfColumnId: '1'
  }, {
    label: '2',
    numberOfColumnId: '2'
  }, {
    label: '3',
    numberOfColumnId: '3'
  }, {
    label: '4',
    numberOfColumnId: '4'
  }, {
    label: '5',
    numberOfColumnId: '5'
  }, {
    label: '6',
    numberOfColumnId: '6'
  }];
  /**
   * Available values for padding (horizontal and vertical) config key
   */

  exports.NUMBER_OF_COLUMNS_OPTIONS = NUMBER_OF_COLUMNS_OPTIONS;
  var PADDING_OPTIONS = [{
    label: '0',
    paddingSize: '0'
  }, {
    label: '1',
    paddingSize: '3'
  }, {
    label: '2',
    paddingSize: '4'
  }, {
    label: '4',
    paddingSize: '5'
  }, {
    label: '6',
    paddingSize: '6'
  }, {
    label: '8',
    paddingSize: '7'
  }, {
    label: '10',
    paddingSize: '8'
  }];
  /**
   * Default component row config
   */

  exports.PADDING_OPTIONS = PADDING_OPTIONS;
  var DEFAULT_COMPONENT_ROW_CONFIG = (_DEFAULT_COMPONENT_RO = {}, _defineProperty(_DEFAULT_COMPONENT_RO, CONFIG_KEYS.columnSpacing, true), _defineProperty(_DEFAULT_COMPONENT_RO, CONFIG_KEYS.paddingHorizontal, DEFAULT_PADDING_SIZE), _defineProperty(_DEFAULT_COMPONENT_RO, CONFIG_KEYS.paddingVertical, DEFAULT_PADDING_SIZE), _DEFAULT_COMPONENT_RO);
  /**
   * Default section row config
   */

  exports.DEFAULT_COMPONENT_ROW_CONFIG = DEFAULT_COMPONENT_ROW_CONFIG;
  var DEFAULT_SECTION_ROW_CONFIG = (_DEFAULT_SECTION_ROW_ = {}, _defineProperty(_DEFAULT_SECTION_ROW_, CONFIG_KEYS.columnSpacing, true), _defineProperty(_DEFAULT_SECTION_ROW_, CONFIG_KEYS.paddingHorizontal, '0'), _defineProperty(_DEFAULT_SECTION_ROW_, CONFIG_KEYS.paddingVertical, '0'), _DEFAULT_SECTION_ROW_);
  exports.DEFAULT_SECTION_ROW_CONFIG = DEFAULT_SECTION_ROW_CONFIG;
  //# sourceMappingURL=rowConstants.js.map
});
//# sourceMappingURL=rowConstants.js.map
